==> slices_cli-0.1.25-py3-none-any.whl: slices_cli/bi_diskimage.py <==
"""BI CLI."""

import json
from typing import Annotated, Optional

import typer
from rich.table import Table
from slices_bi_client.exceptions import ApiException, BadRequestException
from slices_bi_client.models.disk_image_create import DiskImageCreate

from . import console, err_console
from .bi_context import BIContext

disk_images_app = typer.Typer(no_args_is_help=True)


@disk_images_app.command(name="register")
def register_image(
    ctx: BIContext,
    friendly_name: Annotated[str, typer.Option(prompt=True, show_default=False)],
    location: Annotated[str, typer.Option(prompt=True, show_default=False)],
    default_username: Annotated[str, typer.Option(prompt=True, show_default=False)],
    min_disk: Annotated[
        Optional[int],
        typer.Option(show_default=False, help="The minimum size of the root disk, in MB."),
    ] = None,
    min_ram: Annotated[
        Optional[int],
        typer.Option(show_default=False, help="The minimum required amount of RAM for this image, MiB."),
    ] = None,
    tags: Annotated[Optional[list[str]], typer.Option(show_default=False)] = None,
):
    """Register disk images.

    Only available to admin users.
    """

    dic = DiskImageCreate(
        friendly_name=friendly_name,
        cluster_id=ctx.obj.cluster_id,
        location=location,
        default_username=default_username,
    )
    if min_disk:
        dic.min_disk_mb = min_disk
    if min_ram:
        dic.min_ram_mib = min_ram
    if tags:
        dic.tags = tags

    try:
        disk_image = ctx.obj.api.get_bi_images_api(
            ctx.obj.site_id, ctx.obj.require_project_id()
        ).register_disk_image(dic)
        console.print(f"[bold green]:cd: Registered {friendly_name} as {disk_image.id} :white_check_mark:")
    except BadRequestException as exc:
        err_console.print("[bold red]Could not register disk image[/] :x:")
        err_console.print("[red]" + json.loads(exc.body)["detail"]) # type: ignore
        raise typer.Exit(code=1) from None
    except ApiException as exc:
        err_console.print("[bold red]Could not register disk image[/] :x:")
        validation_errors = json.loads(exc.body)["detail"] # type: ignore
        for validation_error in validation_errors:
            err_console.print("[red]" + validation_error["msg"])
        raise typer.Exit(code=1) from None


@disk_images_app.command(name="list")
def list_images(ctx: BIContext):
    """List disk images."""
    images_page = ctx.obj.api.get_bi_images_api(ctx.obj.site_id, ctx.obj.require_project_id()).get_disk_images()

    table = Table("ID", "Name", "Created At", "Tags", title="Images")
    for disk_image in images_page.disk_images:
        table.add_row(
            disk_image.id,
            disk_image.friendly_name,
            disk_image.created_at.astimezone().strftime("%Y-%m-%d %H:%M") if disk_image.created_at else "-",
        )

    console.print(table)

==> slices_cli-0.1.29-py3-none-any.whl: slices_cli/bi_diskimage.py <==
"""BI CLI."""

import json
from typing import Annotated, Optional

import typer
from rich.table import Table
from slices_bi_client.exceptions import ApiException, BadRequestException
from slices_bi_client.models.disk_image_create import DiskImageCreate

from . import console, err_console
from .bi_context import BIContext
from .utils import get_error_detail

disk_images_app = typer.Typer(no_args_is_help=True)


@disk_images_app.command(name="register")
def register_image(
    ctx: BIContext,
    friendly_name: Annotated[str, typer.Option(prompt=True, show_default=False)],
    location: Annotated[str, typer.Option(prompt=True, show_default=False)],
    default_username: Annotated[str, typer.Option(prompt=True, show_default=False)],
    min_disk: Annotated[
        Optional[int],
        typer.Option(show_default=False, help="The minimum size of the root disk, in MB."),
    ] = None,
    min_ram: Annotated[
        Optional[int],
        typer.Option(show_default=False, help="The minimum required amount of RAM for this image, MiB."),
    ] = None,
    tags: Annotated[Optional[list[str]], typer.Option(show_default=False)] = None,
):
    """Register disk images.

    Only available to admin users.
    """

    dic = DiskImageCreate(
        friendly_name=friendly_name,
        cluster_id=ctx.obj.cluster_id,
        location=location,
        default_username=default_username,
    )
    if min_disk:
        dic.min_disk_mb = min_disk
    if min_ram:
        dic.min_ram_mib = min_ram
    if tags:
        dic.tags = tags

    try:
        disk_image = ctx.obj.api.get_bi_images_api(ctx.obj.site_id, ctx.obj.require_project_id()).register_disk_image(
            dic
        )
        console.print(f"[bold green]:cd: Registered {friendly_name} as {disk_image.id} :white_check_mark:")
    except ApiException as err:
        err_console.print("[bold red]Could not register disk image[/] :x:")
        err_console.print(f"[red]{get_error_detail(err.body)}")
        raise typer.Exit(code=1) from None


@disk_images_app.command(name="list")
def list_images(ctx: BIContext):
    """List disk images."""
    images_page = ctx.obj.api.get_bi_images_api(ctx.obj.site_id, ctx.obj.require_project_id()).get_disk_images()

    table = Table("ID", "Name", "Created At", "Tags", title="Images")
    for disk_image in images_page.disk_images:
        table.add_row(
            disk_image.id,
            disk_image.friendly_name,
            disk_image.created_at.astimezone().strftime("%Y-%m-%d %H:%M") if disk_image.created_at else "-",
        )

    console.print(table)
